@@ -68,7 +68,7 @@ _as_pools = {} # keyed to remote name
 def get_fp_sys():
     global _fp_sys
 
-    if _fp_sys == None:
+    if _fp_sys is None:
         _fp_sys = Flatpak.Installation.new_system(None)
 
     return _fp_sys
@@ -213,11 +213,11 @@ def _load_appstream_pool(remote):
 
     _as_pools[remote.get_name()] = pool
 
-def initialize_appstream():
-    thread = threading.Thread(target=_initialize_appstream_thread)
+def initialize_appstream(cb=None):
+    thread = threading.Thread(target=_initialize_appstream_thread, args=(cb,))
     thread.start()
 
-def _initialize_appstream_thread():
+def _initialize_appstream_thread(cb=None):
     fp_sys = get_fp_sys()
 
     global _as_pools
@@ -228,6 +228,8 @@ def _initialize_appstream_thread():
 
         try:
             for remote in fp_sys.list_remotes():
+                if remote.get_noenumerate():
+                    continue
                 _load_appstream_pool(remote)
         except (GLib.Error, Exception) as e:
             try:
@@ -236,6 +238,9 @@ def _initialize_appstream_thread():
                 msg = str(e)
             warn("Installer: Could not initialize appstream components for flatpaks: %s" % msg)
 
+    if (cb):
+        GLib.idle_add(cb)
+
 def get_remote_or_installed_ref(ref, remote_name):
     fp_sys = get_fp_sys()
 
@@ -751,7 +756,7 @@ class FlatpakTransaction():
         if self.task.cancellable.is_cancelled():
             return False
 
-        if self.task.client_progress_cb != None:
+        if self.task.client_progress_cb is not None:
             self.task.has_window = True
             GLib.idle_add(self.task.client_progress_cb, self.task.pkginfo, 0, True, " : ")
         else:
@@ -917,7 +922,7 @@ def _pkginfo_from_file_thread(cache, file, callback):
 
     path = file.get_path()
 
-    if path == None:
+    if path is None:
         warn("Installer: flatpak - no valid .flatpakref path provided")
         return None
 
